package com.huimv.manager.modular.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.huimv.manager.enums.AdminTypeEnum;
import com.huimv.manager.enums.AuthExceptionEnum;
import com.huimv.manager.exception.AuthException;
import com.huimv.manager.exception.RRException;
import com.huimv.manager.modular.entity.MobileUser;
import com.huimv.manager.modular.entity.param.LoginParam;
import com.huimv.manager.modular.repository.MobileUserRepository;
import com.huimv.manager.modular.service.MobileUserService;
import com.huimv.manager.result.R;
import com.huimv.manager.util.JwtUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.DigestUtils;
import org.springframework.util.StringUtils;

import java.util.Objects;

/**
 * @Author yinhao
 * @Date 2021/4/19 18:11
 * @Description
 */
@Service
public class MobileUserServiceImpl implements MobileUserService {

    @Autowired
    private MobileUserRepository mobileUserRepository;

    @Override
    public R login(LoginParam loginParam, String code) {
        String account = loginParam.getAccount();
        String password = loginParam.getPassword();
        if (StringUtils.isEmpty(code)) {
            throw new AuthException(AuthExceptionEnum.CONSTANT_EMPTY_ERROR);
        }
        if (ObjectUtil.hasEmpty(account,password)) {
            throw new AuthException(AuthExceptionEnum.ACCOUNT_PWD_EMPTY);
        }

        MobileUser mobileUser = mobileUserRepository.findByAccount(account);
        if (mobileUser == null) {
            throw new AuthException(AuthExceptionEnum.ACCOUNT_PWD_ERROR);
        }

        if (mobileUser.getGrantClass().equals(AdminTypeEnum.ADMIN.getCode())) {
            throw new RRException("对不起,你不是管理员,不能登录此系统!",401);
        }

        String inputPwdMd5 = DigestUtils.md5DigestAsHex(password.getBytes());
        if (!inputPwdMd5.equals(mobileUser.getPassword())) {
            throw new AuthException(AuthExceptionEnum.ACCOUNT_PWD_ERROR);
        }

        String token =  JwtUtils.getJwtToken(mobileUser.getId());
        mobileUser.setPassword("");
        return Objects.requireNonNull(R.ok().put("token", token)).put("mobileUser",mobileUser);
    }

    @Override
    public MobileUser findById(Integer id) {
        return mobileUserRepository.findById(id).orElse(null);
    }
}
